package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.License;

/**
 * 执照Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface LicenseMapper 
{
    /**
     * 查询执照
     * 
     * @param licenseId 执照主键
     * @return 执照
     */
    public License selectLicenseByLicenseId(Long licenseId);

    /**
     * 查询执照列表
     * 
     * @param license 执照
     * @return 执照集合
     */
    public List<License> selectLicenseList(License license);

    /**
     * 新增执照
     * 
     * @param license 执照
     * @return 结果
     */
    public int insertLicense(License license);

    /**
     * 修改执照
     * 
     * @param license 执照
     * @return 结果
     */
    public int updateLicense(License license);

    /**
     * 删除执照
     * 
     * @param licenseId 执照主键
     * @return 结果
     */
    public int deleteLicenseByLicenseId(Long licenseId);

    /**
     * 批量删除执照
     * 
     * @param licenseIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLicenseByLicenseIds(Long[] licenseIds);

    /**
     * 查询执照列表
     *
     * @return 执照
     */
    List<License> getLicenseList();
}
